@@ -1,10 +1,11 @@
 """Oppo UDP SDK"""
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 
 from .codes import OppoRemoteCode, OppoRemoteCodeType
 from .const import *
 from .exceptions import *
 from .command import *
+from .response.enums import *
 from .client import OppoClient
-from .device import OppoDevice
+from .device import OppoDevice, OppoPlaybackStatus
